@@ -517,6 +517,12 @@ pref("dom.disable_open_click_delay", 1000);
 pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
+// Parsing perf prefs. For now just mimic what the old code did.
+pref("content.sink.event_probe_rate", 3);
+//@line 527 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+pref("content.sink.pending_event_mode", 0);
+//@line 529 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+
 // Disable popups from plugins by default
 //   0 = openAllowed
 //   1 = openControlled
@@ -560,7 +566,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 570 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 576 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -793,7 +799,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 808 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 814 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -812,9 +818,9 @@ pref("network.ntlm.send-lm-response", false);
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 828 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 834 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 835 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 841 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1177,15 +1183,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1576 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1582 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 1993 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 1999 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2194 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2200 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2288 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2294 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2291 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2297 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1453,15 +1459,15 @@ pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER
 // So, we have no reasons we should use non-toplevel window for popup.
 pref("ui.panel.default_level_parent", true);
 
-//@line 2561 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2567 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2629 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2635 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2655 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2661 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2675 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2681 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
-//@line 2683 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2689 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1485,7 +1491,7 @@ pref("image.cache.size", 5242880);
 // Size is given a weight of 1000 - timeweight.
 pref("image.cache.timeweight", 500);
 
-//@line 2712 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
+//@line 2718 "/builds/moz2_slave/mozilla-1.9.1-linux64-xulrunner/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
